summaryrefslogtreecommitdiffstats
path: root/libkdepim/embeddedurlpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/embeddedurlpage.cpp')
-rw-r--r--libkdepim/embeddedurlpage.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkdepim/embeddedurlpage.cpp b/libkdepim/embeddedurlpage.cpp
index d45d532d..c840e3a0 100644
--- a/libkdepim/embeddedurlpage.cpp
+++ b/libkdepim/embeddedurlpage.cpp
@@ -33,8 +33,8 @@
using namespace KPIM;
EmbeddedURLPage::EmbeddedURLPage( const TQString &url, const TQString &mimetype,
- TQWidget *tqparent, const char *name )
- : TQWidget( tqparent, name ), mUri(url), mMimeType( mimetype ), mPart( 0 )
+ TQWidget *parent, const char *name )
+ : TQWidget( parent, name ), mUri(url), mMimeType( mimetype ), mPart( 0 )
{
initGUI( url, mimetype );
}
@@ -54,7 +54,7 @@ void EmbeddedURLPage::loadContents()
TQString mimetype = mMimeType;
if ( mimetype == "auto" )
mimetype == KMimeType::findByURL( mUri )->name();
// "this" is both the tqparent widget and the tqparent object
mPart = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), TQT_TQWIDGET(this), 0, TQT_TQOBJECT(this), 0 );
if ( mPart ) {
mPart->openURL( mUri );
@@ -54,7 +54,7 @@ void EmbeddedURLPage::loadContents()
if ( mimetype == "auto" )
mimetype == KMimeType::findByURL( mUri )->name();
- // "this" is both the tqparent widget and the tqparent object
+ // "this" is both the parent widget and the parent object
mPart = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), TQT_TQWIDGET(this), 0, TQT_TQOBJECT(this), 0 );
if ( mPart ) {